# -*- coding: UTF-8 -*-
"""tests de collecte des différents dictionnaires
(module, locaux et variante)
"""
from py.test import raises
import os.path as osp
from os import remove

from creole.cfgparser import EoleDict
from creole.error import ConfigError

HERE = osp.join(osp.dirname(__file__))
DATADIR = osp.join(HERE, 'data')
DICODIR = osp.join(DATADIR, 'eole', 'dicos')

generated = 'testdicos.output'

def check_filecontent(got, expected):
    """utilitaire de comparaison de 2 fichiers"""
    expected_content = file(expected).read().strip()
    got_content = file(got).read().strip()
    assert got_content == expected_content


def gen_dico():
    """initialisations préalables aux tests
    """
    dico_eole = EoleDict(templatedir=DATADIR)
    dico_eole.read(osp.join(DICODIR, 'general.xml'))
    dico_eole.read(osp.join(DICODIR, 'local', 'local.xml'))
    dico_eole.read(osp.join(DICODIR, 'variante', 'variante.xml'))
    resultfile = osp.join(DATADIR, 'testdicos.result')
    return dico_eole, resultfile

def test_instance():
    """teste l'instanciation après chargement des dictionnaires
    (utilisation des valeurs par défaut)
    """
    dico_eole, resultfile = gen_dico()
    dico_eole.instance()
    yield check_filecontent, generated, resultfile

def test_exists():
    dico_eole, resultfile = gen_dico()
    dico_eole.read(osp.join(DICODIR, 'exists.xml'))
    assert dico_eole.variables['var_general'].description == "variable du dictionnaire general"
    assert dico_eole.variables['var_general2'].description == "creation de description"

def test_variables():
    """teste l'existence des variables provenant des 3 dictionnaires
    """
    dico_eole, resultfile = gen_dico()
    variables = dico_eole.variables.keys()
    assert 'var_general' in variables
    assert 'var_local' in variables
    assert 'var_variante' in variables
    assert dico_eole.family_order == ['general', 'local', 'variante']

def teardown_module(module):
    """suppression des fichiers générés par les tests
    """
    remove(generated)
