# -*- coding: utf-8 -*-
"""
    redefine cas d'utilisation plus précis
"""
from os import path as osp

from py.test import raises
from creole.cfgparser import EoleDict
from creole.error import ConfigError

HERE = osp.join(osp.dirname(__file__))
DATADIR = osp.join(HERE, 'data')
DICODIR = osp.join(DATADIR, 'eole', 'dicos')

def gen_dico():
    """initialisations préalables aux tests
    """
    dico_eole = EoleDict(templatedir=DATADIR, logfile='/dev/null')
    dico_eole.read(osp.join(DICODIR, 'general.xml'))
    dico_eole.read(osp.join(DICODIR, 'local', 'local.xml'))
    dico_eole.read(osp.join(DICODIR, 'variante', 'variante.xml'))
    resultfile = osp.join(DATADIR, 'testdicos.result')
    return dico_eole, resultfile

def test_necessary_redefine():
    dico_eole, resultfile = gen_dico()
    arite = osp.join(DICODIR, 'general3.xml')
    raises(ConfigError, dico_eole.read, arite)

def test_redefine_description():
    dico_eole, resultfile = gen_dico()
    dico_eole.read(osp.join(DICODIR, 'general2.xml'))
    dico_eole.read(osp.join(DICODIR, 'redefine.xml'))
    assert dico_eole.variables['var_general2'].description == "changement de description"

def test_redefine_value():
    """
        valeole, value, hidden, multi
    """
    dico_eole, resultfile = gen_dico()
    dico_eole.read(osp.join(DICODIR, 'general_value.xml'))
    dico_eole.read(osp.join(DICODIR, 'redefine_value.xml'))
    assert dico_eole.variables['var_general2'].get_value() ==  ['12']

def test_redefine_value_auto():
    """
        auto
    """
    dico_eole, resultfile = gen_dico()
    dico_eole.read(osp.join(DICODIR, 'general_value.xml'))
    dico_eole.read(osp.join(DICODIR, 'redefine_value.xml'))
    assert dico_eole.variables['var_general_dependant'].get_value() ==  ['12']

def test_redefine_auto():
    """
        redefine automatiques
    """
    dico_eole, resultfile = gen_dico()
    dico_eole.read(osp.join(DICODIR, 'general_value.xml'))
    dico_eole.read(osp.join(DICODIR, 'redefine_value2.xml'))
    assert dico_eole.variables['var_general_dependant'].get_value() ==  ['13']

def test_redefine_valid_enum():
    """
        test de la redéfinition de valid_enum
    """
    dico_eole, resultfile = gen_dico()
    dico_eole.read(osp.join(DICODIR, 'general_value5.xml'))
    dico_eole.read(osp.join(DICODIR, 'redefine_value5.xml'))
    result = [[u'valid_enum', [{'optional': '', 'type': '', 'name': '', 'value': u"['oui', 'non', 'peut-etre']", 'hidden':''}]]]
    assert dico_eole.variables['var_general2'].checks == result

def test_redefine_check():
    """
        test de la redéfinition de checks
    """
    dico_eole, resultfile = gen_dico()
    dico_eole.read(osp.join(DICODIR, 'general_value6.xml'))
    dico_eole.read(osp.join(DICODIR, 'redefine_value6.xml'))
    assert dico_eole.variables['var_general2'].checks == [[u'obligatoire', []]]

def test_redefine_auto_eolfile():
    """
        test avec fichier config.eol charge
    """
    dico_eole, resultfile = gen_dico()
    dico_eole.read(osp.join(DICODIR, 'general_value.xml'))
    dico_eole.read(osp.join(DICODIR, 'redefine_value2.xml'))
    dico_eole.load_values(osp.join(DATADIR, 'config_redefine.eol'))
    assert dico_eole.variables['var_general_dependant'].get_value() ==  ['13']

def test_redefine_value_fill():
    """
       redéfinit la valeur mais pas le fill
    """
    dico_eole, resultfile = gen_dico()
    dico_eole.read(osp.join(DICODIR, 'general_value2.xml'))
    dico_eole.read(osp.join(DICODIR, 'redefine_value.xml'))
    dico_eole.save_values('/dev/null')
    assert dico_eole.variables['var_general_dependant'].get_value() ==  ['12']

def test_redefine_fill():
    """
        remplissage automatique des variables (valeurs par defaut)
    """
    dico_eole, resultfile = gen_dico()
    dico_eole.read(osp.join(DICODIR, 'general_value3.xml'))
    dico_eole.read(osp.join(DICODIR, 'redefine_value3.xml'))
    dico_eole.save_values('/dev/null')
    assert dico_eole.variables['var_general_dependant'].get_value() ==  ['13']

def test_redefine_fill_eolfile():
    """
    test avec config.eol charge
    """
    dico_eole, resultfile = gen_dico()
    dico_eole.read(osp.join(DICODIR, 'general_value3.xml'))
    #dico_eole.read(osp.join(DICODIR, 'redefine_value3.xml'))
    dico_eole.load_values(osp.join(DATADIR, 'config_redefine.eol'))
    dico_eole.save_values('/dev/null')
    assert dico_eole.variables['var_general_dependant'].get_value() ==  ['1']

def test_redefine_hidden_if_in():
    """
        prise en compte du hiddden_if_in
    """
    dico_eole, resultfile = gen_dico()
    dico_eole.read(osp.join(DICODIR, 'general_value4.xml'))
    dico_eole.read(osp.join(DICODIR, 'redefine_value4.xml'))
    dico_eole.save_values('/dev/null')
    assert dico_eole.variables['var_general2'].hidden ==  False

def test_not_redefine_multi():
    """
       l'attribut multi n'est pas modifiable
    """
    dico_eole, resultfile = gen_dico()
    assert dico_eole.variables['multi1'].multi == True
    assert dico_eole.variables['multi2'].multi == True
    assert dico_eole.variables['non_multi1'].multi == False
    assert dico_eole.variables['non_multi2'].multi == False
    dico_eole.read(osp.join(DICODIR, 'redefine_multi.xml'))
    assert dico_eole.variables['multi1'].multi == True
    assert dico_eole.variables['multi2'].multi == True
    assert dico_eole.variables['non_multi1'].multi == False
    assert dico_eole.variables['non_multi2'].multi == False
