# -*- coding: UTF-8 -*-
"""
test du comportement de la classe Template
"""
from creole.template import Template
from py.test import raises
from creole.error import *
from creole.typeole import *
from creole.cfgparser import *
from creole import typeole
from os.path import join, abspath, splitext, dirname, basename
from os import unlink

def setup_module(module):
    module.test_dir = join(abspath(dirname(__file__)), splitext(basename(__file__))[0])
    module.target_dir = join(abspath(dirname(__file__)), 'target')
    # simulation d'un EoleDict
    module.dico = EoleDict()
    module.dico.variables['ip_eth'] = typeole.type_factory('string', 'ip_eth', val=['ip0', 'ip1', 'ip2'])
    module.dico.variables['nom_etab'] = typeole.type_factory('string', 'nom_etab', val=['etab'])
    module.dico.variables['vrai'] = typeole.type_factory('boolean', 'vrai', val=[True])
    module.dico.variables['faux'] = typeole.type_factory('string', 'faux', val=['faux'])
    module.dico.variables['toto'] = typeole.type_factory('string', 'toto', val=['toto'])
    module.files = ['forin.txt', 'testif.txt', 'badvariable.txt', 'end.txt', 'foreach.txt', 'dest.txt']
    # création des target (les fichiers cibles sont censés exister)
    for target in module.files:
        file_h = file(join(module.target_dir, target), 'w')
        file_h.close()
    
def test_notfound():
    """
    levée d'exceptions attendues si tout n'est pas disponible à la création du template
    """
    # mauvais fichier source
    t = Template(join(target_dir,'existepas.txt'), templatedir= test_dir)
    raises(FileNotFound, """t.verify()""")
    # mauvais répertoire source
    t = Template(join(target_dir,'demo.txt'), templatedir= '/reperoire/qui/n/existe/pas')
    raises(FileNotFound, """t.verify()""")
    # mauvais répertoire destination
    t = Template(join('/reperoire/qui/n/existe/pas','demo.txt'), templatedir= test_dir)
    raises(FileNotFound, """t.verify()""")
    # fichiers de destination non préexistant
    t = Template(join(target_dir,'pasdetarget.txt'), templatedir= test_dir)
    raises(FileNotFound, t.verify)

def test_pretest():
    """test de dictionnaire : ce test devrait être déplacé"""
    
    # si ce test ne passe plus c'est que l'API de EoleDict a changé :)
    assert dico.get_value('ip_eth') == ['ip0', 'ip1', 'ip2']
    assert dico.get_value('nom_etab') == ['etab']

def test_source():
    """test de la validation d'un template
    FIXME : la méthode verify pourrait être renommée"""
    
    t = Template(join(target_dir,'src_pas.txt'), templatedir= test_dir)
    raises(FileNotFound, """t.verify()""")
    t = Template(join(target_dir,'dest.txt'), templatedir= test_dir)
    # test du cas où le fichier source a un autre nom que le fichier de destination
    t = Template(join(target_dir, 'dest.txt'), templatedir=test_dir, source='src2.txt')
    t.verify() # normalement OK
    assert t.filename == join(test_dir, 'src2.txt')

def teardown_module(module):
    
    for target in module.files:
        filename = join(module.target_dir, target)
        unlink(filename)
