# -*- coding: UTF-8 -*-
"""Typage des variables creole dans *typeole.py*"""

from py.test import raises
from creole import typeole
from creole.error import *


def test_init():
    """initialisation de variables"""
    test = typeole.EoleVar('mavariable')
    assert hasattr(test, 'val')
    assert hasattr(test, 'valprec')
    assert hasattr(test, 'valdefault')
    assert hasattr(test, 'valeole')
    assert hasattr(test, 'description')
    test.set_value('valeur')
    test.set_value('defaut', default=True)
    assert test.val == ['valeur']
    assert test.valdefault == ['defaut']

def test_factory():
    """levée d'exception de variables via la type factory"""
    raises(TypeEoleError, """typeole.type_factory('dtc', 'mavar')""")
    raises(TypeEoleError, """typeole.type_factory(1, 'mavar')""")

def test_ip():
    """test variables de type ip"""
    test = typeole.Ip('var_ip')
    raises(TypeEoleError, """test.set_value(["zou"])""")
    raises(TypeEoleError, """test.set_value(["999.999.999.999"])""")
    raises(TypeEoleError, """test.set_value(["1.1.1.1","999.999.999.999"])""")
    test.set_value(['192.168.230.26','192.168.230.22'])
    assert test.val == ['192.168.230.26','192.168.230.22']

def test_mask():
    """test variables de type masque"""
    test = typeole.type_factory('netmask', 'monnetmask')
    raises(TypeEoleError, """test.set_value("[999.999.999.999]")""")
    raises(TypeEoleError, """test.set_value("[192.168.230.26]")""")
    test.set_value(['255.255.255.0'])
    assert test.val == ['255.255.255.0']

def test_get():
    """utilisation des valeurs par défaut"""
    # tests avec une valeur par défaut eole
    test=typeole.type_factory('string', 'description', valeole=["eole"])
    assert test.get_value() == ["eole"]
    assert test.get_value(default=True) == ["eole"]
    test.set_value(["val"])
    assert test.get_value() == ["val"]
    assert test.get_value(default=True) == ["eole"]
    # tests avec les 2 valeurs par défaut
    test2=typeole.type_factory('string', 'description', valeole=["eole"], valdefault=["def"])
    assert test2.get_value() == ["def"]
    assert test2.get_value(default=True) == ["def"]
    test2.set_value(["val"])
    assert test2.get_value() == ["val"]
    assert test2.get_value(default=True) == ["def"]

def test_checks():
    """renseigner une type, exception sur le passage d'un mauvais type"""
    # nb : valid_entier fait un cast sur les chaines
    ## format anonyme
    test=typeole.EoleVar('unevariable', checks=[['valid_entier', [{'value':10}, {'value':20}] ]])
    raises(TypeEoleError, """test.set_value(["5"])""")
    raises(TypeEoleError, """test.set_value(["18", "19", "20", "21" ])""")
    test.set_value(['15', '16', '17']) # ok
    raises(TypeEoleError, """test.set_value(["meme pas un entier"])""")
    ## TODO format nommé
    test=typeole.EoleVar('unevariable', checks=[['valid_entier', [{ 'name':'mini', 'value':10 },
                                                                  { 'name':'maxi', 'value': 20 }]
                                               ]])
    raises(TypeEoleError, """test.set_value(["5"])""")
    raises(TypeEoleError, """test.set_value(["18", "19", "20", "21" ])""")
    test.set_value(['15', '16', '17']) # ok
    raises(TypeEoleError, """test.set_value(["meme pas un entier"])""")


